@@ -109,7 +109,7 @@ plot.highlod <- function(x, ..., quant.level = NULL, sliding = FALSE)
       quant.level <- quant.level$max.lod.quant
     
     ## Need to supply quant.level as second argument.
-    slidingbar.plot(slidingbar.create(x, quant.level, ...))
+    slidingbar.plot(slidingbar.create(x, quant.level, ...), ...)
   }
   else
     plot(hotsize(x, ..., quant.level = quant.level), ...)
@@ -133,15 +133,14 @@ cat.scanone <- function(dirpath = ".", filenames = permfiles, chr.pos)
   ## Folder should contain scanone highlods data across all traits for ONE permutation
   permfiles <- list.files(dirpath, paste("per.scan", "*", "RData", sep = "."))
 
-  ## Make and remove per.scan.hl. Below use version from attached files.
+  ## Make and remove per.scan.hl. Below use version from files.
   per.scan.hl <- NULL
   rm(per.scan.hl)
   
-  for(i in 1:length(filenames)){
-    attach(filenames[i], warn.conflicts = FALSE)
-    if(i==1)  highobj <- per.scan.hl else
-    highobj <- rbind.data.frame(highobj, per.scan.hl)
-    detach()
+  for(i in 1:length(filenames)) {
+    highobj <- with(filenames[i], {
+      if(i==1) per.scan.hl else rbind.data.frame(highobj, per.scan.hl)
+    })
   }
   cbind.data.frame(chr.pos[highobj$row,],highobj)
 }
